@@ -114,6 +114,10 @@
 #' @param stats.label.args Additional arguments that will be passed to `ggrepel
 #'   geom_label_repel` geom. Please see documentation for that function to know
 #'   more about these arguments.
+#' @param package Name of package from which the palette is desired as string
+#' or symbol.
+#' @param palette Name of palette as string or symbol.
+#' @param direction Either `1` or `-1`. If `-1` the palette will be reversed.
 #' @param only.significant If `TRUE`, only stats labels for significant effects
 #'   is shown (Default: `FALSE`). This can be helpful when a large number of
 #'   regression coefficients are to be displayed in a single plot. Relevant only
@@ -128,7 +132,6 @@
 #' @inheritParams broom::tidy.polr
 #' @inheritParams broom::tidy.mjoint
 #' @inheritParams theme_ggstatsplot
-#' @inheritParams paletteer::paletteer_d
 #' @inheritParams subtitle_meta_ggcoefstats
 #' @inheritParams ggbetweenstats
 #'
@@ -353,12 +356,10 @@ ggcoefstats <- function(x,
       "blmerMod",
       "brmsfit",
       "brmsfit_multiple",
-      "gamlss",
       "glmmadmb",
       "glmerMod",
       "glmmPQL",
       "glmmTMB",
-      "gls",
       "lme",
       "lmerMod",
       "mcmc",
@@ -367,11 +368,9 @@ ggcoefstats <- function(x,
       "nlmerMod",
       "rjags",
       "rlmerMod",
-      "stanfit",
       "stanreg",
       "stanmvreg",
-      "TMB",
-      "wblm"
+      "TMB"
     )
 
   # =================== types of models =====================================
@@ -478,6 +477,7 @@ ggcoefstats <- function(x,
           x = x,
           conf.int = conf.int,
           conf.level = conf.level,
+          effects = "fixed",
           se.type = se.type,
           by_class = by.class,
           component = component,
@@ -550,7 +550,7 @@ ggcoefstats <- function(x,
       tidyr::unite(
         data = .,
         col = "term",
-        dplyr::matches("term|variable|parameter|method|curveid|curve|response"),
+        dplyr::matches("term|variable|parameter|method|curve|response"),
         remove = TRUE,
         sep = "_"
       )
@@ -847,11 +847,7 @@ ggcoefstats <- function(x,
     # if needed, adding the vertical line
     if (isTRUE(vline)) {
       # either at 1 - if coefficients are to be exponentiated - or at 0
-      if (isTRUE(exponentiate)) {
-        xintercept <- 1
-      } else {
-        xintercept <- 0
-      }
+      xintercept <- ifelse(exponentiate, 1, 0)
 
       # adding the line geom
       plot <- plot +
@@ -928,8 +924,7 @@ ggcoefstats <- function(x,
       if (is.null(stats.label.color)) {
         stats.label.color <-
           paletteer::paletteer_d(
-            package = !!package,
-            palette = !!palette,
+            palette = paste0(package, "::", palette),
             n = count_term,
             direction = direction,
             type = "discrete"
