@@ -82,8 +82,11 @@
 #'   `insig = "pch"`). Defaults are `pch.col = "#F0E442"` and `pch.cex = 10`.
 #' @param tl.cex,tl.col,tl.srt The size, the color, and the string rotation of
 #'   text label (variable names, i.e.).
+#' @param package Name of package from which the palette is desired as string
+#' or symbol.
+#' @param palette Name of palette as string or symbol.
+#' @param direction Either `1` or `-1`. If `-1` the palette will be reversed.
 #' @inheritParams theme_ggstatsplot
-#' @inheritParams paletteer::paletteer_d
 #' @inheritParams ggscatterstats
 #'
 #' @import ggplot2
@@ -265,10 +268,10 @@ ggcorrmat <- function(data,
     )
 
   # ===================== statistics ========================================
-  #
+
   if (corr.method %in% c("pearson", "spearman", "kendall")) {
     # compute confidence intervals only when requested by the user
-    ci <- ifelse(test = output == "ci", yes = TRUE, no = FALSE)
+    ci <- ifelse(output == "ci", yes = TRUE, no = FALSE)
 
     # computing correlations using `psych` package
     corr_df <-
@@ -278,7 +281,7 @@ ggcorrmat <- function(data,
         use = "pairwise",
         method = corr.method,
         adjust = p.adjust.method,
-        alpha = .05,
+        alpha = 0.05,
         ci = ci,
         minlength = 20
       )
@@ -327,8 +330,7 @@ ggcorrmat <- function(data,
   # if user has not specified colors, then use a color palette
   if (is.null(colors)) {
     colors <- paletteer::paletteer_d(
-      package = !!package,
-      palette = !!palette,
+      palette = paste0(package, "::", palette),
       n = 3,
       direction = direction,
       type = "discrete"
@@ -471,7 +473,8 @@ ggcorrmat <- function(data,
       tibble_helper <- purrr::compose(tibble::as_tibble, tibble::rownames_to_column)
 
       # merging data frame with CIs and adjusted CIs
-      ci.mat <- list(corr_df$ci, corr_df$ci.adj) %>%
+      ci.mat <-
+        list(corr_df$ci, corr_df$ci.adj) %>%
         purrr::map(.x = ., .f = tibble_helper, var = "pair") %>%
         dplyr::bind_cols(.) %>%
         dplyr::select(.data = ., pair, r, dplyr::everything(), -pair1)
