@@ -1,15 +1,3 @@
-# function to extract all numbers from text results from helper functions
-num_parser <- function(ggstats.obj) {
-  suppressWarnings(readr::parse_number(
-    x = as.character(ggstats.obj),
-    na = "NA"
-  )) %>%
-    tibble::enframe(x = .) %>%
-    dplyr::select(.data = ., value) %>%
-    dplyr::filter(.data = ., !is.na(value)) %>%
-    purrr::flatten_dbl(.x = .)
-}
-
 # function to compare lists
 compare_list <- function(a, b) {
   # computing length of two lists
@@ -50,12 +38,7 @@ formals_comparator <- function(.f1, .f2) {
     ) %>%
     dplyr::filter(
       .data = .,
-      !name %in% c(
-        "data",
-        "grouping.var",
-        "...",
-        "condition"
-      )
+      !name %in% c("data", "grouping.var", "...", "condition")
     )
 
   # comparison list
@@ -64,7 +47,7 @@ formals_comparator <- function(.f1, .f2) {
   # count the number of discrepancies between formals defaults
   discrepancies <-
     purrr::map_dfc(.x = df_list, .f = rlang::is_false) %>%
-    tidyr::gather(data = .) %>%
+    tidyr::gather(.) %>%
     dplyr::summarise(.data = ., error = sum(value))
 
   # retuen the dataframe
