@@ -152,7 +152,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("V")["Cramer"],
+          widehat(italic("V")["Cramer"]),
           " = ",
           "0.22",
           ", CI"["95%"],
@@ -184,7 +184,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("V")["Cramer"],
+          widehat(italic("V")["Cramer"]),
           " = ",
           "0.34",
           ", CI"["95%"],
