@@ -95,7 +95,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "2.32",
           ", CI"["95%"],
@@ -126,7 +126,7 @@ testthat::test_that(
           " = ",
           "0.075",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "0.55",
           ", CI"["95%"],
@@ -157,7 +157,7 @@ testthat::test_that(
           " = ",
           "0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "-1.38",
           ", CI"["95%"],
