@@ -146,8 +146,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          omega^
-            2,
+          widehat(omega^2),
           " = ",
           "0.98",
           ", CI"["95%"],
@@ -180,7 +179,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.95",
           ", CI"["95%"],
@@ -213,7 +212,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.94",
           ", CI"["95%"],
@@ -272,7 +271,7 @@ testthat::test_that(
           " = ",
           "0.424",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.00",
           ", CI"["95%"],
@@ -305,7 +304,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.08",
           ", CI"["95%"],
